# bioDAG

This is a package to preprocess DAG-structure biological data. Now, it supports
* [MeSH](https://www.ncbi.nlm.nih.gov/mesh)

## DESCRIPTION
___
### MeSH
There are some contents to introduce workflow and functions for MeSH

### Release Notes
___
#### version 0.0.2
<ul>
    <li>Optimize logic of __init__ file</li>
    <li>Fix bugs of importing MeSHDAG and MeSHDAGTerm</li>
</ul>

